ldap

package
v1.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2020 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthenticateUser

func AuthenticateUser(username string, password string) (*string, *string, error)

Authenticate a user through LDAP or LDS return if bind was ok, the userDN for next usage, and error if occurred

func GetAllGroups

func GetAllGroups() ([]string, error)

Authenticate a user through LDAP or LDS return if bind was ok, the userDN for next usage, and error if occurred

func GetUserGroups

func GetUserGroups(userDN string) ([]string, error)

Authenticate a user through LDAP or LDS return if bind was ok, the userDN for next usage, and error if occurred

func HasAdminAccess

func HasAdminAccess(userDN string) bool

Check if a user is in admin LDAP group return true if it belong to AdminGroup, false otherwise

func HasApplicationAccess

func HasApplicationAccess(userDN string) bool

Check if a user is in admin LDAP group return true if it belong to ApplicationGroup, false otherwise

func HasOpsAccess

func HasOpsAccess(userDN string) bool

Check if a user is in admin LDAP group return true if it belong to OpsGroup, false otherwise

Types

type Authenticator

type Authenticator struct {
}

Jump to