Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CagipV1Client ¶
type CagipV1Client struct {
// contains filtered or unexported fields
}
CagipV1Client is used to interact with features provided by the cagip.github.com group.
func New ¶
func New(c rest.Interface) *CagipV1Client
New creates a new CagipV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CagipV1Client, error)
NewForConfig creates a new CagipV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new CagipV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CagipV1Client
NewForConfigOrDie creates a new CagipV1Client for the given config and panics if there is an error in the config.
func (*CagipV1Client) NetworkPolicyConfigs ¶
func (c *CagipV1Client) NetworkPolicyConfigs() NetworkPolicyConfigInterface
func (*CagipV1Client) Projects ¶
func (c *CagipV1Client) Projects() ProjectInterface
func (*CagipV1Client) RESTClient ¶
func (c *CagipV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CagipV1Interface ¶
type CagipV1Interface interface {
RESTClient() rest.Interface
NetworkPolicyConfigsGetter
ProjectsGetter
}
type NetworkPolicyConfigExpansion ¶
type NetworkPolicyConfigExpansion interface{}
type NetworkPolicyConfigInterface ¶
type NetworkPolicyConfigInterface interface {
Create(ctx context.Context, networkPolicyConfig *v1.NetworkPolicyConfig, opts metav1.CreateOptions) (*v1.NetworkPolicyConfig, error)
Update(ctx context.Context, networkPolicyConfig *v1.NetworkPolicyConfig, opts metav1.UpdateOptions) (*v1.NetworkPolicyConfig, error)
UpdateStatus(ctx context.Context, networkPolicyConfig *v1.NetworkPolicyConfig, opts metav1.UpdateOptions) (*v1.NetworkPolicyConfig, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.NetworkPolicyConfig, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.NetworkPolicyConfigList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.NetworkPolicyConfig, err error)
NetworkPolicyConfigExpansion
}
NetworkPolicyConfigInterface has methods to work with NetworkPolicyConfig resources.
type NetworkPolicyConfigsGetter ¶
type NetworkPolicyConfigsGetter interface {
NetworkPolicyConfigs() NetworkPolicyConfigInterface
}
NetworkPolicyConfigsGetter has a method to return a NetworkPolicyConfigInterface. A group's client should implement this interface.
type ProjectExpansion ¶
type ProjectExpansion interface{}
type ProjectInterface ¶
type ProjectInterface interface {
Create(ctx context.Context, project *v1.Project, opts metav1.CreateOptions) (*v1.Project, error)
Update(ctx context.Context, project *v1.Project, opts metav1.UpdateOptions) (*v1.Project, error)
UpdateStatus(ctx context.Context, project *v1.Project, opts metav1.UpdateOptions) (*v1.Project, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.Project, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ProjectList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Project, err error)
ProjectExpansion
}
ProjectInterface has methods to work with Project resources.
type ProjectsGetter ¶
type ProjectsGetter interface {
Projects() ProjectInterface
}
ProjectsGetter has a method to return a ProjectInterface. A group's client should implement this interface.