Documentation
¶
Index ¶
- func AuthenticateUser(username string, password string) (*string, *string, error)
- func GetAllGroups() ([]string, error)
- func GetUserGroups(userDN string) ([]string, error)
- func HasAdminAccess(userDN string) bool
- func HasApplicationAccess(userDN string) bool
- func HasOpsAccess(userDN string) bool
- type Authenticator
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuthenticateUser ¶
Authenticate a user through LDAP or LDS return if bind was ok, the userDN for next usage, and error if occurred
func GetAllGroups ¶
Authenticate a user through LDAP or LDS return if bind was ok, the userDN for next usage, and error if occurred
func GetUserGroups ¶
Authenticate a user through LDAP or LDS return if bind was ok, the userDN for next usage, and error if occurred
func HasAdminAccess ¶
Check if a user is in admin LDAP group return true if it belong to AdminGroup, false otherwise
func HasApplicationAccess ¶
Check if a user is in admin LDAP group return true if it belong to ApplicationGroup, false otherwise
func HasOpsAccess ¶
Check if a user is in admin LDAP group return true if it belong to OpsGroup, false otherwise
Types ¶
type Authenticator ¶
type Authenticator struct {
}
Click to show internal directories.
Click to hide internal directories.